@@ -1,4 +1,5 @@
-// Copyright (c) 2020 Red Hat, Inc.
+// Copyright (c) 2021 Red Hat, Inc.
+// Copyright Contributors to the Open Cluster Management project
 
 package main
 
@@ -11,7 +12,7 @@ import (
 	"github.com/spf13/pflag"
 	"k8s.io/klog"
 
-	"github.com/stolostron/grafana-dashboard-loader/pkg/controller"
+	"github.com/open-cluster-management/grafana-dashboard-loader/pkg/controller"
 )
 
 func main() {
@@ -24,7 +25,7 @@ func main() {
 	// use a channel to synchronize the finalization for a graceful shutdown
 	stop := make(chan struct{})
 	defer close(stop)
-	
+
 	controller.RunGrafanaDashboardController(stop)
 
 	// use a channel to handle OS signals to terminate and gracefully shut
